"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.Cipher = exports.Compression = exports.Hash = void 0;

var _reactNative = require("react-native");

var model = _interopRequireWildcard(require("./bridge"));

var flatbuffers = _interopRequireWildcard(require("flatbuffers"));

var _boolResponse = require("./model/bool-response");

var _decryptRequest = require("./model/decrypt-request");

var _decryptSymmetricRequest = require("./model/decrypt-symmetric-request");

var _encryptRequest = require("./model/encrypt-request");

var _encryptSymmetricRequest = require("./model/encrypt-symmetric-request");

var _generateRequest = require("./model/generate-request");

var _keyPairResponse = require("./model/key-pair-response");

var _signRequest = require("./model/sign-request");

var _stringResponse = require("./model/string-response");

var _verifyRequest = require("./model/verify-request");

var _decryptSymmetricFileRequest = require("./model/decrypt-symmetric-file-request");

var _encryptSymmetricFileRequest = require("./model/encrypt-symmetric-file-request");

var _intResponse = require("./model/int-response");

var _decryptFileRequest = require("./model/decrypt-file-request");

var _encryptFileRequest = require("./model/encrypt-file-request");

var _signFileRequest = require("./model/sign-file-request");

var _verifyFileRequest = require("./model/verify-file-request");

var _publicKeyMetadataResponse = require("./model/public-key-metadata-response");

var _privateKeyMetadataResponse = require("./model/private-key-metadata-response");

var _getPublicKeyMetadataRequest = require("./model/get-public-key-metadata-request");

var _getPrivateKeyMetadataRequest = require("./model/get-private-key-metadata-request");

var _convertPrivateKeyToPublicKeyRequest = require("./model/convert-private-key-to-public-key-request");

require("./shim");

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

const FastOpenPGPNativeModules = _reactNative.NativeModules.FastOpenPGP;
let Hash;
exports.Hash = Hash;

(function (Hash) {
  Hash[Hash["SHA256"] = 0] = "SHA256";
  Hash[Hash["SHA224"] = 1] = "SHA224";
  Hash[Hash["SHA384"] = 2] = "SHA384";
  Hash[Hash["SHA512"] = 3] = "SHA512";
})(Hash || (exports.Hash = Hash = {}));

let Compression;
exports.Compression = Compression;

(function (Compression) {
  Compression[Compression["NONE"] = 0] = "NONE";
  Compression[Compression["ZLIB"] = 1] = "ZLIB";
  Compression[Compression["ZIP"] = 2] = "ZIP";
})(Compression || (exports.Compression = Compression = {}));

let Cipher;
exports.Cipher = Cipher;

(function (Cipher) {
  Cipher[Cipher["AES128"] = 0] = "AES128";
  Cipher[Cipher["AES192"] = 1] = "AES192";
  Cipher[Cipher["AES256"] = 2] = "AES256";
})(Cipher || (exports.Cipher = Cipher = {}));

class OpenPGP {
  /**
   * for now we recommend use this in false because is sync
   */
  static async decrypt(message, privateKey, passphrase, options) {
    const builder = new flatbuffers.Builder(0);
    const messageOffset = builder.createString(message);
    const passphraseOffset = builder.createString(passphrase);
    const privateKeyOffset = builder.createString(privateKey);

    const optionsOffset = this._keyOptions(builder, options);

    _decryptRequest.DecryptRequest.startDecryptRequest(builder);

    typeof optionsOffset !== 'undefined' && _decryptRequest.DecryptRequest.addOptions(builder, optionsOffset);

    _decryptRequest.DecryptRequest.addMessage(builder, messageOffset);

    _decryptRequest.DecryptRequest.addPassphrase(builder, passphraseOffset);

    _decryptRequest.DecryptRequest.addPrivateKey(builder, privateKeyOffset);

    const offset = _decryptRequest.DecryptRequest.endDecryptRequest(builder);

    builder.finish(offset);
    const result = await this.call('decrypt', builder.asUint8Array());
    return this._stringResponse(result);
  }

  static async decryptFile(inputFile, outputFile, privateKey, passphrase, options) {
    const builder = new flatbuffers.Builder(0);
    const inputOffset = builder.createString(inputFile);
    const outputOffset = builder.createString(outputFile);
    const passphraseOffset = builder.createString(passphrase);
    const privateKeyOffset = builder.createString(privateKey);

    const optionsOffset = this._keyOptions(builder, options);

    _decryptFileRequest.DecryptFileRequest.startDecryptFileRequest(builder);

    typeof optionsOffset !== 'undefined' && _decryptFileRequest.DecryptFileRequest.addOptions(builder, optionsOffset);

    _decryptFileRequest.DecryptFileRequest.addInput(builder, inputOffset);

    _decryptFileRequest.DecryptFileRequest.addOutput(builder, outputOffset);

    _decryptFileRequest.DecryptFileRequest.addPassphrase(builder, passphraseOffset);

    _decryptFileRequest.DecryptFileRequest.addPrivateKey(builder, privateKeyOffset);

    const offset = _decryptFileRequest.DecryptFileRequest.endDecryptFileRequest(builder);

    builder.finish(offset);
    const result = await this.call('decryptFile', builder.asUint8Array());
    return this._intResponse(result);
  }

  static async encrypt(message, publicKey, signedEntity, fileHints, options) {
    const builder = new flatbuffers.Builder(0);
    const messageOffset = builder.createString(message);
    const publicKeyOffset = builder.createString(publicKey);

    const optionsOffset = this._keyOptions(builder, options);

    const fileHintsOffset = this._fileHints(builder, fileHints);

    const signedEntityOffset = this._entity(builder, signedEntity);

    _encryptRequest.EncryptRequest.startEncryptRequest(builder);

    typeof optionsOffset !== 'undefined' && _encryptRequest.EncryptRequest.addOptions(builder, optionsOffset);
    typeof fileHintsOffset !== 'undefined' && _encryptRequest.EncryptRequest.addFileHints(builder, fileHintsOffset);
    typeof signedEntityOffset !== 'undefined' && _encryptRequest.EncryptRequest.addSigned(builder, signedEntityOffset);

    _encryptRequest.EncryptRequest.addMessage(builder, messageOffset);

    _encryptRequest.EncryptRequest.addPublicKey(builder, publicKeyOffset);

    const offset = _encryptRequest.EncryptRequest.endEncryptRequest(builder);

    builder.finish(offset);
    const result = await this.call('encrypt', builder.asUint8Array());
    return this._stringResponse(result);
  }

  static async encryptFile(inputFile, outputFile, publicKey, signedEntity, fileHints, options) {
    const builder = new flatbuffers.Builder(0);
    const inputOffset = builder.createString(inputFile);
    const outputOffset = builder.createString(outputFile);
    const publicKeyOffset = builder.createString(publicKey);

    const optionsOffset = this._keyOptions(builder, options);

    const fileHintsOffset = this._fileHints(builder, fileHints);

    const signedEntityOffset = this._entity(builder, signedEntity);

    _encryptFileRequest.EncryptFileRequest.startEncryptFileRequest(builder);

    typeof optionsOffset !== 'undefined' && _encryptFileRequest.EncryptFileRequest.addOptions(builder, optionsOffset);
    typeof fileHintsOffset !== 'undefined' && _encryptFileRequest.EncryptFileRequest.addFileHints(builder, fileHintsOffset);
    typeof signedEntityOffset !== 'undefined' && _encryptFileRequest.EncryptFileRequest.addSigned(builder, signedEntityOffset);

    _encryptFileRequest.EncryptFileRequest.addInput(builder, inputOffset);

    _encryptFileRequest.EncryptFileRequest.addOutput(builder, outputOffset);

    _encryptFileRequest.EncryptFileRequest.addPublicKey(builder, publicKeyOffset);

    const offset = _encryptFileRequest.EncryptFileRequest.endEncryptFileRequest(builder);

    builder.finish(offset);
    const result = await this.call('encryptFile', builder.asUint8Array());
    return this._intResponse(result);
  }

  static async sign(message, publicKey, privateKey, passphrase, options) {
    const builder = new flatbuffers.Builder(0);
    const messageOffset = builder.createString(message);
    const publicKeyOffset = builder.createString(publicKey);
    const privateKeyOffset = builder.createString(privateKey);
    const passphraseOffset = builder.createString(passphrase);

    const optionsOffset = this._keyOptions(builder, options);

    _signRequest.SignRequest.startSignRequest(builder);

    typeof optionsOffset !== 'undefined' && _signRequest.SignRequest.addOptions(builder, optionsOffset);

    _signRequest.SignRequest.addMessage(builder, messageOffset);

    _signRequest.SignRequest.addPublicKey(builder, publicKeyOffset);

    _signRequest.SignRequest.addPrivateKey(builder, privateKeyOffset);

    _signRequest.SignRequest.addPassphrase(builder, passphraseOffset);

    const offset = _signRequest.SignRequest.endSignRequest(builder);

    builder.finish(offset);
    const result = await this.call('sign', builder.asUint8Array());
    return this._stringResponse(result);
  }

  static async signFile(inputFile, publicKey, privateKey, passphrase, options) {
    const builder = new flatbuffers.Builder(0);
    const inputFileOffset = builder.createString(inputFile);
    const publicKeyOffset = builder.createString(publicKey);
    const privateKeyOffset = builder.createString(privateKey);
    const passphraseOffset = builder.createString(passphrase);

    const optionsOffset = this._keyOptions(builder, options);

    _signFileRequest.SignFileRequest.startSignFileRequest(builder);

    typeof optionsOffset !== 'undefined' && _signFileRequest.SignFileRequest.addOptions(builder, optionsOffset);

    _signFileRequest.SignFileRequest.addInput(builder, inputFileOffset);

    _signFileRequest.SignFileRequest.addPublicKey(builder, publicKeyOffset);

    _signFileRequest.SignFileRequest.addPrivateKey(builder, privateKeyOffset);

    _signFileRequest.SignFileRequest.addPassphrase(builder, passphraseOffset);

    const offset = _signFileRequest.SignFileRequest.endSignFileRequest(builder);

    builder.finish(offset);
    const result = await this.call('signFile', builder.asUint8Array());
    return this._stringResponse(result);
  }

  static async verify(signature, message, publicKey) {
    const builder = new flatbuffers.Builder(0);
    const messageOffset = builder.createString(message);
    const publicKeyOffset = builder.createString(publicKey);
    const signatureOffset = builder.createString(signature);

    _verifyRequest.VerifyRequest.startVerifyRequest(builder);

    _verifyRequest.VerifyRequest.addMessage(builder, messageOffset);

    _verifyRequest.VerifyRequest.addPublicKey(builder, publicKeyOffset);

    _verifyRequest.VerifyRequest.addSignature(builder, signatureOffset);

    const offset = _verifyRequest.VerifyRequest.endVerifyRequest(builder);

    builder.finish(offset);
    const result = await this.call('verify', builder.asUint8Array());
    return this._boolResponse(result);
  }

  static async verifyFile(signature, inputFile, publicKey) {
    const builder = new flatbuffers.Builder(0);
    const inputFileOffset = builder.createString(inputFile);
    const publicKeyOffset = builder.createString(publicKey);
    const signatureOffset = builder.createString(signature);

    _verifyFileRequest.VerifyFileRequest.startVerifyFileRequest(builder);

    _verifyFileRequest.VerifyFileRequest.addInput(builder, inputFileOffset);

    _verifyFileRequest.VerifyFileRequest.addPublicKey(builder, publicKeyOffset);

    _verifyFileRequest.VerifyFileRequest.addSignature(builder, signatureOffset);

    const offset = _verifyFileRequest.VerifyFileRequest.endVerifyFileRequest(builder);

    builder.finish(offset);
    const result = await this.call('verifyFile', builder.asUint8Array());
    return this._boolResponse(result);
  }

  static async decryptSymmetric(message, passphrase, options) {
    const builder = new flatbuffers.Builder(0);
    const messageOffset = builder.createString(message);
    const passphraseOffset = builder.createString(passphrase);

    const optionsOffset = this._keyOptions(builder, options);

    _decryptSymmetricRequest.DecryptSymmetricRequest.startDecryptSymmetricRequest(builder);

    typeof optionsOffset !== 'undefined' && _decryptSymmetricRequest.DecryptSymmetricRequest.addOptions(builder, optionsOffset);

    _decryptSymmetricRequest.DecryptSymmetricRequest.addMessage(builder, messageOffset);

    _decryptSymmetricRequest.DecryptSymmetricRequest.addPassphrase(builder, passphraseOffset);

    const offset = _decryptSymmetricRequest.DecryptSymmetricRequest.endDecryptSymmetricRequest(builder);

    builder.finish(offset);
    const result = await this.call('decryptSymmetric', builder.asUint8Array());
    return this._stringResponse(result);
  }

  static async decryptSymmetricFile(inputFile, outputFile, passphrase, options) {
    const builder = new flatbuffers.Builder(0);
    const inputOffset = builder.createString(inputFile);
    const outputOffset = builder.createString(outputFile);
    const passphraseOffset = builder.createString(passphrase);

    const optionsOffset = this._keyOptions(builder, options);

    _decryptSymmetricFileRequest.DecryptSymmetricFileRequest.startDecryptSymmetricFileRequest(builder);

    typeof optionsOffset !== 'undefined' && _decryptSymmetricFileRequest.DecryptSymmetricFileRequest.addOptions(builder, optionsOffset);

    _decryptSymmetricFileRequest.DecryptSymmetricFileRequest.addInput(builder, inputOffset);

    _decryptSymmetricFileRequest.DecryptSymmetricFileRequest.addOutput(builder, outputOffset);

    _decryptSymmetricFileRequest.DecryptSymmetricFileRequest.addPassphrase(builder, passphraseOffset);

    const offset = _decryptSymmetricFileRequest.DecryptSymmetricFileRequest.endDecryptSymmetricFileRequest(builder);

    builder.finish(offset);
    const result = await this.call('decryptSymmetricFile', builder.asUint8Array());
    return this._intResponse(result);
  }

  static async encryptSymmetric(message, passphrase, fileHints, options) {
    const builder = new flatbuffers.Builder(0);
    const messageOffset = builder.createString(message);
    const passphraseOffset = builder.createString(passphrase);

    const optionsOffset = this._keyOptions(builder, options);

    const fileHintsOffset = this._fileHints(builder, fileHints);

    _encryptSymmetricRequest.EncryptSymmetricRequest.startEncryptSymmetricRequest(builder);

    typeof optionsOffset !== 'undefined' && _encryptSymmetricRequest.EncryptSymmetricRequest.addOptions(builder, optionsOffset);
    typeof fileHintsOffset !== 'undefined' && _encryptSymmetricRequest.EncryptSymmetricRequest.addFileHints(builder, fileHintsOffset);

    _encryptSymmetricRequest.EncryptSymmetricRequest.addMessage(builder, messageOffset);

    _encryptSymmetricRequest.EncryptSymmetricRequest.addPassphrase(builder, passphraseOffset);

    const offset = _encryptSymmetricRequest.EncryptSymmetricRequest.endEncryptSymmetricRequest(builder);

    builder.finish(offset);
    const result = await this.call('encryptSymmetric', builder.asUint8Array());
    return this._stringResponse(result);
  }

  static async encryptSymmetricFile(inputFile, outputFile, passphrase, fileHints, options) {
    const builder = new flatbuffers.Builder(0);
    const inputOffset = builder.createString(inputFile);
    const outputOffset = builder.createString(outputFile);
    const passphraseOffset = builder.createString(passphrase);

    const optionsOffset = this._keyOptions(builder, options);

    const fileHintsOffset = this._fileHints(builder, fileHints);

    _encryptSymmetricFileRequest.EncryptSymmetricFileRequest.startEncryptSymmetricFileRequest(builder);

    typeof optionsOffset !== 'undefined' && _encryptSymmetricFileRequest.EncryptSymmetricFileRequest.addOptions(builder, optionsOffset);
    typeof fileHintsOffset !== 'undefined' && _encryptSymmetricFileRequest.EncryptSymmetricFileRequest.addFileHints(builder, fileHintsOffset);

    _encryptSymmetricFileRequest.EncryptSymmetricFileRequest.addInput(builder, inputOffset);

    _encryptSymmetricFileRequest.EncryptSymmetricFileRequest.addOutput(builder, outputOffset);

    _encryptSymmetricFileRequest.EncryptSymmetricFileRequest.addPassphrase(builder, passphraseOffset);

    const offset = _encryptSymmetricFileRequest.EncryptSymmetricFileRequest.endEncryptSymmetricFileRequest(builder);

    builder.finish(offset);
    const result = await this.call('encryptSymmetricFile', builder.asUint8Array());
    return this._intResponse(result);
  }

  static async generate(options) {
    const builder = new flatbuffers.Builder(0);

    const optionsOffset = this._options(builder, options);

    _generateRequest.GenerateRequest.startGenerateRequest(builder);

    typeof optionsOffset !== 'undefined' && _generateRequest.GenerateRequest.addOptions(builder, optionsOffset);

    const offset = _generateRequest.GenerateRequest.endGenerateRequest(builder);

    builder.finish(offset);
    const result = await this.call('generate', builder.asUint8Array());
    return this._keyPairResponse(result);
  }

  static async getPrivateKeyMetadata(privateKey) {
    const builder = new flatbuffers.Builder(0);
    const privateKeyOffset = builder.createString(privateKey);

    _getPrivateKeyMetadataRequest.GetPrivateKeyMetadataRequest.startGetPrivateKeyMetadataRequest(builder);

    _getPrivateKeyMetadataRequest.GetPrivateKeyMetadataRequest.addPrivateKey(builder, privateKeyOffset);

    const offset = _getPrivateKeyMetadataRequest.GetPrivateKeyMetadataRequest.endGetPrivateKeyMetadataRequest(builder);

    builder.finish(offset);
    const result = await this.call('getPrivateKeyMetadata', builder.asUint8Array());
    return this._privateKeyMetadataResponse(result);
  }

  static async getPublicKeyMetadata(publicKey) {
    const builder = new flatbuffers.Builder(0);
    const publicKeyOffset = builder.createString(publicKey);

    _getPublicKeyMetadataRequest.GetPublicKeyMetadataRequest.startGetPublicKeyMetadataRequest(builder);

    _getPublicKeyMetadataRequest.GetPublicKeyMetadataRequest.addPublicKey(builder, publicKeyOffset);

    const offset = _getPublicKeyMetadataRequest.GetPublicKeyMetadataRequest.endGetPublicKeyMetadataRequest(builder);

    builder.finish(offset);
    const result = await this.call('getPublicKeyMetadata', builder.asUint8Array());
    return this._publiKeyMetadataResponse(result);
  }

  static async convertPrivateKeyToPublicKey(privateKey) {
    const builder = new flatbuffers.Builder(0);
    const privateKeyOffset = builder.createString(privateKey);

    _convertPrivateKeyToPublicKeyRequest.ConvertPrivateKeyToPublicKeyRequest.startConvertPrivateKeyToPublicKeyRequest(builder);

    _convertPrivateKeyToPublicKeyRequest.ConvertPrivateKeyToPublicKeyRequest.addPrivateKey(builder, privateKeyOffset);

    const offset = _convertPrivateKeyToPublicKeyRequest.ConvertPrivateKeyToPublicKeyRequest.endConvertPrivateKeyToPublicKeyRequest(builder);

    builder.finish(offset);
    const result = await this.call('convertPrivateKeyToPublicKey', builder.asUint8Array());
    return this._stringResponse(result);
  }

  static async call(name, bytes) {
    try {
      let result;

      if (this.useJSI) {
        if (!this.loaded) {
          this.loaded = await FastOpenPGPNativeModules.install();
          console.log(this.TAG, `(${name})`, 'JSI install:', this.loaded ? 'Installed' : 'Not Installed');
        }

        if (this.loaded) {
          const buff = bytes.buffer.slice(bytes.byteOffset, bytes.byteLength + bytes.byteOffset);
          result = await global.FastOpenPGPCallPromise(name, buff);

          if (typeof result === 'string') {
            throw new Error(result);
          }
        } else {
          console.log(this.TAG, `(${name})`, 'cant use JSI in debug mode, fallback to NativeModules');
          result = await FastOpenPGPNativeModules.callJSI(name, Array.from(bytes));
        }
      } else {
        result = await FastOpenPGPNativeModules.call(name, Array.from(bytes));
      }

      return this._responseBuffer(result);
    } catch (e) {
      throw e;
    }
  }

  static _responseBuffer(result) {
    if (!result) {
      throw new Error('empty result');
    }

    var rawResponse;

    if (result.hasOwnProperty('length')) {
      const resultArray = result;
      rawResponse = new Uint8Array(resultArray);
    } else {
      const resultBytes = result;
      rawResponse = new Uint8Array(resultBytes, 0, resultBytes.byteLength);
    }

    return new flatbuffers.ByteBuffer(rawResponse);
  }

  static _stringResponse(result) {
    const response = _stringResponse.StringResponse.getRootAsStringResponse(result);

    const error = response.error();

    if (error) {
      throw new Error('stringResponse: ' + error);
    }

    return response.output() || '';
  }

  static _intResponse(result) {
    const response = _intResponse.IntResponse.getRootAsIntResponse(result);

    const error = response.error();

    if (error) {
      throw new Error('intResponse: ' + error);
    }

    return Number(response.output());
  }

  static _boolResponse(result) {
    const response = _boolResponse.BoolResponse.getRootAsBoolResponse(result);

    const error = response.error();

    if (error) {
      throw new Error('boolResponse: ' + error);
    }

    return response.output();
  }

  static _entity(builder, options) {
    var _options$passphrase;

    if (!options) {
      return;
    }

    const passphraseOffset = builder.createString((_options$passphrase = options.passphrase) !== null && _options$passphrase !== void 0 ? _options$passphrase : '');
    const privateKeyOffset = builder.createString(options.privateKey);
    const publicKeyOffset = builder.createString(options.publicKey);
    model.Entity.startEntity(builder);
    model.Entity.addPassphrase(builder, passphraseOffset);
    model.Entity.addPrivateKey(builder, privateKeyOffset);
    model.Entity.addPublicKey(builder, publicKeyOffset);
    return model.Entity.endEntity(builder);
  }

  static _fileHints(builder, options) {
    var _options$fileName, _options$modTime, _options$isBinary;

    if (!options) {
      return;
    }

    const fileNameOffset = builder.createString((_options$fileName = options.fileName) !== null && _options$fileName !== void 0 ? _options$fileName : '');
    const modTimeOffset = builder.createString((_options$modTime = options.modTime) !== null && _options$modTime !== void 0 ? _options$modTime : '');
    model.FileHints.startFileHints(builder);
    model.FileHints.addFileName(builder, fileNameOffset);
    model.FileHints.addModTime(builder, modTimeOffset);
    model.FileHints.addIsBinary(builder, (_options$isBinary = options.isBinary) !== null && _options$isBinary !== void 0 ? _options$isBinary : false);
    return model.FileHints.endFileHints(builder);
  }

  static _keyOptions(builder, options) {
    if (!options) {
      return;
    }

    model.KeyOptions.startKeyOptions(builder);
    typeof options.cipher !== 'undefined' && model.KeyOptions.addCipher(builder, options.cipher);
    typeof options.compression !== 'undefined' && model.KeyOptions.addCompression(builder, options.compression);
    typeof options.compressionLevel !== 'undefined' && model.KeyOptions.addCompressionLevel(builder, options.compressionLevel);
    typeof options.hash !== 'undefined' && model.KeyOptions.addHash(builder, options.hash);
    typeof options.rsaBits !== 'undefined' && model.KeyOptions.addRsaBits(builder, options.rsaBits);
    return model.KeyOptions.endKeyOptions(builder);
  }

  static _options(builder, options) {
    var _options$name, _options$comment, _options$email, _options$passphrase2;

    if (!options) {
      return;
    }

    const nameOffset = builder.createString((_options$name = options.name) !== null && _options$name !== void 0 ? _options$name : '');
    const commentOffset = builder.createString((_options$comment = options.comment) !== null && _options$comment !== void 0 ? _options$comment : '');
    const emailOffset = builder.createString((_options$email = options.email) !== null && _options$email !== void 0 ? _options$email : '');
    const passphraseOffset = builder.createString((_options$passphrase2 = options.passphrase) !== null && _options$passphrase2 !== void 0 ? _options$passphrase2 : '');

    const keyOffset = this._keyOptions(builder, options.keyOptions);

    model.Options.startOptions(builder);
    model.Options.addName(builder, nameOffset);
    model.Options.addComment(builder, commentOffset);
    model.Options.addEmail(builder, emailOffset);
    model.Options.addPassphrase(builder, passphraseOffset);
    typeof keyOffset !== 'undefined' && model.Options.addKeyOptions(builder, keyOffset);
    return model.Options.endOptions(builder);
  }

  static _keyPairResponse(result) {
    const response = _keyPairResponse.KeyPairResponse.getRootAsKeyPairResponse(result);

    const error = response.error();

    if (error) {
      throw new Error('keyPairResponse: ' + error);
    }

    const output = response.output();

    if (!output) {
      throw new Error('empty output');
    }

    return {
      privateKey: output.privateKey() || '',
      publicKey: output.publicKey() || ''
    };
  }

  static _publiKeyMetadataResponse(result) {
    const response = _publicKeyMetadataResponse.PublicKeyMetadataResponse.getRootAsPublicKeyMetadataResponse(result);

    const error = response.error();

    if (error) {
      throw new Error('publicKeyMetadataResponse: ' + error);
    }

    const output = response.output();

    if (!output) {
      throw new Error('empty output');
    }

    return {
      keyID: output.keyId() || '',
      keyIDShort: output.keyIdShort() || '',
      creationTime: output.creationTime() || '',
      fingerprint: output.fingerprint() || '',
      keyIDNumeric: output.keyIdNumeric() || '',
      isSubKey: output.isSubKey()
    };
  }

  static _privateKeyMetadataResponse(result) {
    const response = _privateKeyMetadataResponse.PrivateKeyMetadataResponse.getRootAsPrivateKeyMetadataResponse(result);

    const error = response.error();

    if (error) {
      throw new Error('privateKeyMetadataResponse: ' + error);
    }

    const output = response.output();

    if (!output) {
      throw new Error('empty output');
    }

    return {
      keyID: output.keyId() || '',
      keyIDShort: output.keyIdShort() || '',
      creationTime: output.creationTime() || '',
      fingerprint: output.fingerprint() || '',
      keyIDNumeric: output.keyIdNumeric() || '',
      isSubKey: output.isSubKey(),
      encrypted: output.encrypted()
    };
  }

}

exports.default = OpenPGP;

_defineProperty(OpenPGP, "useJSI", false);

_defineProperty(OpenPGP, "loaded", false);

_defineProperty(OpenPGP, "TAG", '[FastOpenPGP]');
//# sourceMappingURL=index.js.map