"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.FileHints = void 0;

var flatbuffers = _interopRequireWildcard(require("flatbuffers"));

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

class FileHints {
  constructor() {
    _defineProperty(this, "bb", null);

    _defineProperty(this, "bb_pos", 0);
  }

  __init(i, bb) {
    this.bb_pos = i;
    this.bb = bb;
    return this;
  }

  static getRootAsFileHints(bb, obj) {
    return (obj || new FileHints()).__init(bb.readInt32(bb.position()) + bb.position(), bb);
  }

  static getSizePrefixedRootAsFileHints(bb, obj) {
    bb.setPosition(bb.position() + flatbuffers.SIZE_PREFIX_LENGTH);
    return (obj || new FileHints()).__init(bb.readInt32(bb.position()) + bb.position(), bb);
  }
  /**
   * IsBinary can be set to hint that the contents are binary data.
   */


  isBinary() {
    const offset = this.bb.__offset(this.bb_pos, 4);

    return offset ? !!this.bb.readInt8(this.bb_pos + offset) : false;
  }

  mutate_is_binary(value) {
    const offset = this.bb.__offset(this.bb_pos, 4);

    if (offset === 0) {
      return false;
    }

    this.bb.writeInt8(this.bb_pos + offset, +value);
    return true;
  }
  /**
   * FileName hints at the name of the file that should be written. It's
   * truncated to 255 bytes if longer. It may be empty to suggest that the
   * file should not be written to disk. It may be equal to "_CONSOLE" to
   * suggest the data should not be written to disk.
   */


  fileName(optionalEncoding) {
    const offset = this.bb.__offset(this.bb_pos, 6);

    return offset ? this.bb.__string(this.bb_pos + offset, optionalEncoding) : null;
  }
  /**
   * ModTime format allowed: RFC3339, contains the modification time of the file, or the zero time if not applicable.
   */


  modTime(optionalEncoding) {
    const offset = this.bb.__offset(this.bb_pos, 8);

    return offset ? this.bb.__string(this.bb_pos + offset, optionalEncoding) : null;
  }

  static startFileHints(builder) {
    builder.startObject(3);
  }

  static addIsBinary(builder, isBinary) {
    builder.addFieldInt8(0, +isBinary, +false);
  }

  static addFileName(builder, fileNameOffset) {
    builder.addFieldOffset(1, fileNameOffset, 0);
  }

  static addModTime(builder, modTimeOffset) {
    builder.addFieldOffset(2, modTimeOffset, 0);
  }

  static endFileHints(builder) {
    const offset = builder.endObject();
    return offset;
  }

  static createFileHints(builder, isBinary, fileNameOffset, modTimeOffset) {
    FileHints.startFileHints(builder);
    FileHints.addIsBinary(builder, isBinary);
    FileHints.addFileName(builder, fileNameOffset);
    FileHints.addModTime(builder, modTimeOffset);
    return FileHints.endFileHints(builder);
  }

}

exports.FileHints = FileHints;
//# sourceMappingURL=file-hints.js.map