"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.KeyOptions = void 0;

var flatbuffers = _interopRequireWildcard(require("flatbuffers"));

var _cipher = require("../model/cipher");

var _compression = require("../model/compression");

var _hash = require("../model/hash");

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * KeyOptions collects a number of parameters along with sensible defaults.
 */
class KeyOptions {
  constructor() {
    _defineProperty(this, "bb", null);

    _defineProperty(this, "bb_pos", 0);
  }

  __init(i, bb) {
    this.bb_pos = i;
    this.bb = bb;
    return this;
  }

  static getRootAsKeyOptions(bb, obj) {
    return (obj || new KeyOptions()).__init(bb.readInt32(bb.position()) + bb.position(), bb);
  }

  static getSizePrefixedRootAsKeyOptions(bb, obj) {
    bb.setPosition(bb.position() + flatbuffers.SIZE_PREFIX_LENGTH);
    return (obj || new KeyOptions()).__init(bb.readInt32(bb.position()) + bb.position(), bb);
  }
  /**
   * Hash is the default hash function to be used.
   * If zero, SHA-256 is used.
   */


  hash() {
    const offset = this.bb.__offset(this.bb_pos, 4);

    return offset ? this.bb.readInt32(this.bb_pos + offset) : _hash.Hash.SHA256;
  }

  mutate_hash(value) {
    const offset = this.bb.__offset(this.bb_pos, 4);

    if (offset === 0) {
      return false;
    }

    this.bb.writeInt32(this.bb_pos + offset, value);
    return true;
  }
  /**
   * Cipher is the cipher to be used.
   * If zero, AES-128 is used.
   */


  cipher() {
    const offset = this.bb.__offset(this.bb_pos, 6);

    return offset ? this.bb.readInt32(this.bb_pos + offset) : _cipher.Cipher.AES128;
  }

  mutate_cipher(value) {
    const offset = this.bb.__offset(this.bb_pos, 6);

    if (offset === 0) {
      return false;
    }

    this.bb.writeInt32(this.bb_pos + offset, value);
    return true;
  }
  /**
   * Compression is the compression algorithm to be
   * applied to the plaintext before encryption. If zero, no
   * compression is done.
   */


  compression() {
    const offset = this.bb.__offset(this.bb_pos, 8);

    return offset ? this.bb.readInt32(this.bb_pos + offset) : _compression.Compression.NONE;
  }

  mutate_compression(value) {
    const offset = this.bb.__offset(this.bb_pos, 8);

    if (offset === 0) {
      return false;
    }

    this.bb.writeInt32(this.bb_pos + offset, value);
    return true;
  }
  /**
   * CompressionLevel is the compression level to use. It must be set to
   * between -1 and 9, with -1 causing the compressor to use the
   * default compression level, 0 causing the compressor to use
   * no compression and 1 to 9 representing increasing (better,
   * slower) compression levels. If Level is less than -1 or
   * more then 9, a non-nil error will be returned during
   * encryption. See the constants above for convenient common
   * settings for Level.
   */


  compressionLevel() {
    const offset = this.bb.__offset(this.bb_pos, 10);

    return offset ? this.bb.readInt32(this.bb_pos + offset) : 0;
  }

  mutate_compression_level(value) {
    const offset = this.bb.__offset(this.bb_pos, 10);

    if (offset === 0) {
      return false;
    }

    this.bb.writeInt32(this.bb_pos + offset, value);
    return true;
  }
  /**
   * RSABits is the number of bits in new RSA keys made with NewEntity.
   * If zero, then 2048 bit keys are created.
   */


  rsaBits() {
    const offset = this.bb.__offset(this.bb_pos, 12);

    return offset ? this.bb.readInt32(this.bb_pos + offset) : 0;
  }

  mutate_rsa_bits(value) {
    const offset = this.bb.__offset(this.bb_pos, 12);

    if (offset === 0) {
      return false;
    }

    this.bb.writeInt32(this.bb_pos + offset, value);
    return true;
  }

  static startKeyOptions(builder) {
    builder.startObject(5);
  }

  static addHash(builder, hash) {
    builder.addFieldInt32(0, hash, _hash.Hash.SHA256);
  }

  static addCipher(builder, cipher) {
    builder.addFieldInt32(1, cipher, _cipher.Cipher.AES128);
  }

  static addCompression(builder, compression) {
    builder.addFieldInt32(2, compression, _compression.Compression.NONE);
  }

  static addCompressionLevel(builder, compressionLevel) {
    builder.addFieldInt32(3, compressionLevel, 0);
  }

  static addRsaBits(builder, rsaBits) {
    builder.addFieldInt32(4, rsaBits, 0);
  }

  static endKeyOptions(builder) {
    const offset = builder.endObject();
    return offset;
  }

  static createKeyOptions(builder, hash, cipher, compression, compressionLevel, rsaBits) {
    KeyOptions.startKeyOptions(builder);
    KeyOptions.addHash(builder, hash);
    KeyOptions.addCipher(builder, cipher);
    KeyOptions.addCompression(builder, compression);
    KeyOptions.addCompressionLevel(builder, compressionLevel);
    KeyOptions.addRsaBits(builder, rsaBits);
    return KeyOptions.endKeyOptions(builder);
  }

}

exports.KeyOptions = KeyOptions;
//# sourceMappingURL=key-options.js.map