function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import { NativeModules } from 'react-native';
import * as model from './bridge';
import * as flatbuffers from 'flatbuffers';
import { BoolResponse } from './model/bool-response';
import { DecryptRequest } from './model/decrypt-request';
import { DecryptSymmetricRequest } from './model/decrypt-symmetric-request';
import { EncryptRequest } from './model/encrypt-request';
import { EncryptSymmetricRequest } from './model/encrypt-symmetric-request';
import { GenerateRequest } from './model/generate-request';
import { KeyPairResponse } from './model/key-pair-response';
import { SignRequest } from './model/sign-request';
import { StringResponse } from './model/string-response';
import { VerifyRequest } from './model/verify-request';
import { DecryptSymmetricFileRequest } from './model/decrypt-symmetric-file-request';
import { EncryptSymmetricFileRequest } from './model/encrypt-symmetric-file-request';
import { IntResponse } from './model/int-response';
import { DecryptFileRequest } from './model/decrypt-file-request';
import { EncryptFileRequest } from './model/encrypt-file-request';
import { SignFileRequest } from './model/sign-file-request';
import { VerifyFileRequest } from './model/verify-file-request';
import { PublicKeyMetadataResponse } from './model/public-key-metadata-response';
import { PrivateKeyMetadataResponse } from './model/private-key-metadata-response';
import { GetPublicKeyMetadataRequest } from './model/get-public-key-metadata-request';
import { GetPrivateKeyMetadataRequest } from './model/get-private-key-metadata-request';
import { ConvertPrivateKeyToPublicKeyRequest } from './model/convert-private-key-to-public-key-request';
import './shim';
const FastOpenPGPNativeModules = NativeModules.FastOpenPGP;
export let Hash;

(function (Hash) {
  Hash[Hash["SHA256"] = 0] = "SHA256";
  Hash[Hash["SHA224"] = 1] = "SHA224";
  Hash[Hash["SHA384"] = 2] = "SHA384";
  Hash[Hash["SHA512"] = 3] = "SHA512";
})(Hash || (Hash = {}));

export let Compression;

(function (Compression) {
  Compression[Compression["NONE"] = 0] = "NONE";
  Compression[Compression["ZLIB"] = 1] = "ZLIB";
  Compression[Compression["ZIP"] = 2] = "ZIP";
})(Compression || (Compression = {}));

export let Cipher;

(function (Cipher) {
  Cipher[Cipher["AES128"] = 0] = "AES128";
  Cipher[Cipher["AES192"] = 1] = "AES192";
  Cipher[Cipher["AES256"] = 2] = "AES256";
})(Cipher || (Cipher = {}));

export default class OpenPGP {
  /**
   * for now we recommend use this in false because is sync
   */
  static async decrypt(message, privateKey, passphrase, options) {
    const builder = new flatbuffers.Builder(0);
    const messageOffset = builder.createString(message);
    const passphraseOffset = builder.createString(passphrase);
    const privateKeyOffset = builder.createString(privateKey);

    const optionsOffset = this._keyOptions(builder, options);

    DecryptRequest.startDecryptRequest(builder);
    typeof optionsOffset !== 'undefined' && DecryptRequest.addOptions(builder, optionsOffset);
    DecryptRequest.addMessage(builder, messageOffset);
    DecryptRequest.addPassphrase(builder, passphraseOffset);
    DecryptRequest.addPrivateKey(builder, privateKeyOffset);
    const offset = DecryptRequest.endDecryptRequest(builder);
    builder.finish(offset);
    const result = await this.call('decrypt', builder.asUint8Array());
    return this._stringResponse(result);
  }

  static async decryptFile(inputFile, outputFile, privateKey, passphrase, options) {
    const builder = new flatbuffers.Builder(0);
    const inputOffset = builder.createString(inputFile);
    const outputOffset = builder.createString(outputFile);
    const passphraseOffset = builder.createString(passphrase);
    const privateKeyOffset = builder.createString(privateKey);

    const optionsOffset = this._keyOptions(builder, options);

    DecryptFileRequest.startDecryptFileRequest(builder);
    typeof optionsOffset !== 'undefined' && DecryptFileRequest.addOptions(builder, optionsOffset);
    DecryptFileRequest.addInput(builder, inputOffset);
    DecryptFileRequest.addOutput(builder, outputOffset);
    DecryptFileRequest.addPassphrase(builder, passphraseOffset);
    DecryptFileRequest.addPrivateKey(builder, privateKeyOffset);
    const offset = DecryptFileRequest.endDecryptFileRequest(builder);
    builder.finish(offset);
    const result = await this.call('decryptFile', builder.asUint8Array());
    return this._intResponse(result);
  }

  static async encrypt(message, publicKey, signedEntity, fileHints, options) {
    const builder = new flatbuffers.Builder(0);
    const messageOffset = builder.createString(message);
    const publicKeyOffset = builder.createString(publicKey);

    const optionsOffset = this._keyOptions(builder, options);

    const fileHintsOffset = this._fileHints(builder, fileHints);

    const signedEntityOffset = this._entity(builder, signedEntity);

    EncryptRequest.startEncryptRequest(builder);
    typeof optionsOffset !== 'undefined' && EncryptRequest.addOptions(builder, optionsOffset);
    typeof fileHintsOffset !== 'undefined' && EncryptRequest.addFileHints(builder, fileHintsOffset);
    typeof signedEntityOffset !== 'undefined' && EncryptRequest.addSigned(builder, signedEntityOffset);
    EncryptRequest.addMessage(builder, messageOffset);
    EncryptRequest.addPublicKey(builder, publicKeyOffset);
    const offset = EncryptRequest.endEncryptRequest(builder);
    builder.finish(offset);
    const result = await this.call('encrypt', builder.asUint8Array());
    return this._stringResponse(result);
  }

  static async encryptFile(inputFile, outputFile, publicKey, signedEntity, fileHints, options) {
    const builder = new flatbuffers.Builder(0);
    const inputOffset = builder.createString(inputFile);
    const outputOffset = builder.createString(outputFile);
    const publicKeyOffset = builder.createString(publicKey);

    const optionsOffset = this._keyOptions(builder, options);

    const fileHintsOffset = this._fileHints(builder, fileHints);

    const signedEntityOffset = this._entity(builder, signedEntity);

    EncryptFileRequest.startEncryptFileRequest(builder);
    typeof optionsOffset !== 'undefined' && EncryptFileRequest.addOptions(builder, optionsOffset);
    typeof fileHintsOffset !== 'undefined' && EncryptFileRequest.addFileHints(builder, fileHintsOffset);
    typeof signedEntityOffset !== 'undefined' && EncryptFileRequest.addSigned(builder, signedEntityOffset);
    EncryptFileRequest.addInput(builder, inputOffset);
    EncryptFileRequest.addOutput(builder, outputOffset);
    EncryptFileRequest.addPublicKey(builder, publicKeyOffset);
    const offset = EncryptFileRequest.endEncryptFileRequest(builder);
    builder.finish(offset);
    const result = await this.call('encryptFile', builder.asUint8Array());
    return this._intResponse(result);
  }

  static async sign(message, publicKey, privateKey, passphrase, options) {
    const builder = new flatbuffers.Builder(0);
    const messageOffset = builder.createString(message);
    const publicKeyOffset = builder.createString(publicKey);
    const privateKeyOffset = builder.createString(privateKey);
    const passphraseOffset = builder.createString(passphrase);

    const optionsOffset = this._keyOptions(builder, options);

    SignRequest.startSignRequest(builder);
    typeof optionsOffset !== 'undefined' && SignRequest.addOptions(builder, optionsOffset);
    SignRequest.addMessage(builder, messageOffset);
    SignRequest.addPublicKey(builder, publicKeyOffset);
    SignRequest.addPrivateKey(builder, privateKeyOffset);
    SignRequest.addPassphrase(builder, passphraseOffset);
    const offset = SignRequest.endSignRequest(builder);
    builder.finish(offset);
    const result = await this.call('sign', builder.asUint8Array());
    return this._stringResponse(result);
  }

  static async signFile(inputFile, publicKey, privateKey, passphrase, options) {
    const builder = new flatbuffers.Builder(0);
    const inputFileOffset = builder.createString(inputFile);
    const publicKeyOffset = builder.createString(publicKey);
    const privateKeyOffset = builder.createString(privateKey);
    const passphraseOffset = builder.createString(passphrase);

    const optionsOffset = this._keyOptions(builder, options);

    SignFileRequest.startSignFileRequest(builder);
    typeof optionsOffset !== 'undefined' && SignFileRequest.addOptions(builder, optionsOffset);
    SignFileRequest.addInput(builder, inputFileOffset);
    SignFileRequest.addPublicKey(builder, publicKeyOffset);
    SignFileRequest.addPrivateKey(builder, privateKeyOffset);
    SignFileRequest.addPassphrase(builder, passphraseOffset);
    const offset = SignFileRequest.endSignFileRequest(builder);
    builder.finish(offset);
    const result = await this.call('signFile', builder.asUint8Array());
    return this._stringResponse(result);
  }

  static async verify(signature, message, publicKey) {
    const builder = new flatbuffers.Builder(0);
    const messageOffset = builder.createString(message);
    const publicKeyOffset = builder.createString(publicKey);
    const signatureOffset = builder.createString(signature);
    VerifyRequest.startVerifyRequest(builder);
    VerifyRequest.addMessage(builder, messageOffset);
    VerifyRequest.addPublicKey(builder, publicKeyOffset);
    VerifyRequest.addSignature(builder, signatureOffset);
    const offset = VerifyRequest.endVerifyRequest(builder);
    builder.finish(offset);
    const result = await this.call('verify', builder.asUint8Array());
    return this._boolResponse(result);
  }

  static async verifyFile(signature, inputFile, publicKey) {
    const builder = new flatbuffers.Builder(0);
    const inputFileOffset = builder.createString(inputFile);
    const publicKeyOffset = builder.createString(publicKey);
    const signatureOffset = builder.createString(signature);
    VerifyFileRequest.startVerifyFileRequest(builder);
    VerifyFileRequest.addInput(builder, inputFileOffset);
    VerifyFileRequest.addPublicKey(builder, publicKeyOffset);
    VerifyFileRequest.addSignature(builder, signatureOffset);
    const offset = VerifyFileRequest.endVerifyFileRequest(builder);
    builder.finish(offset);
    const result = await this.call('verifyFile', builder.asUint8Array());
    return this._boolResponse(result);
  }

  static async decryptSymmetric(message, passphrase, options) {
    const builder = new flatbuffers.Builder(0);
    const messageOffset = builder.createString(message);
    const passphraseOffset = builder.createString(passphrase);

    const optionsOffset = this._keyOptions(builder, options);

    DecryptSymmetricRequest.startDecryptSymmetricRequest(builder);
    typeof optionsOffset !== 'undefined' && DecryptSymmetricRequest.addOptions(builder, optionsOffset);
    DecryptSymmetricRequest.addMessage(builder, messageOffset);
    DecryptSymmetricRequest.addPassphrase(builder, passphraseOffset);
    const offset = DecryptSymmetricRequest.endDecryptSymmetricRequest(builder);
    builder.finish(offset);
    const result = await this.call('decryptSymmetric', builder.asUint8Array());
    return this._stringResponse(result);
  }

  static async decryptSymmetricFile(inputFile, outputFile, passphrase, options) {
    const builder = new flatbuffers.Builder(0);
    const inputOffset = builder.createString(inputFile);
    const outputOffset = builder.createString(outputFile);
    const passphraseOffset = builder.createString(passphrase);

    const optionsOffset = this._keyOptions(builder, options);

    DecryptSymmetricFileRequest.startDecryptSymmetricFileRequest(builder);
    typeof optionsOffset !== 'undefined' && DecryptSymmetricFileRequest.addOptions(builder, optionsOffset);
    DecryptSymmetricFileRequest.addInput(builder, inputOffset);
    DecryptSymmetricFileRequest.addOutput(builder, outputOffset);
    DecryptSymmetricFileRequest.addPassphrase(builder, passphraseOffset);
    const offset = DecryptSymmetricFileRequest.endDecryptSymmetricFileRequest(builder);
    builder.finish(offset);
    const result = await this.call('decryptSymmetricFile', builder.asUint8Array());
    return this._intResponse(result);
  }

  static async encryptSymmetric(message, passphrase, fileHints, options) {
    const builder = new flatbuffers.Builder(0);
    const messageOffset = builder.createString(message);
    const passphraseOffset = builder.createString(passphrase);

    const optionsOffset = this._keyOptions(builder, options);

    const fileHintsOffset = this._fileHints(builder, fileHints);

    EncryptSymmetricRequest.startEncryptSymmetricRequest(builder);
    typeof optionsOffset !== 'undefined' && EncryptSymmetricRequest.addOptions(builder, optionsOffset);
    typeof fileHintsOffset !== 'undefined' && EncryptSymmetricRequest.addFileHints(builder, fileHintsOffset);
    EncryptSymmetricRequest.addMessage(builder, messageOffset);
    EncryptSymmetricRequest.addPassphrase(builder, passphraseOffset);
    const offset = EncryptSymmetricRequest.endEncryptSymmetricRequest(builder);
    builder.finish(offset);
    const result = await this.call('encryptSymmetric', builder.asUint8Array());
    return this._stringResponse(result);
  }

  static async encryptSymmetricFile(inputFile, outputFile, passphrase, fileHints, options) {
    const builder = new flatbuffers.Builder(0);
    const inputOffset = builder.createString(inputFile);
    const outputOffset = builder.createString(outputFile);
    const passphraseOffset = builder.createString(passphrase);

    const optionsOffset = this._keyOptions(builder, options);

    const fileHintsOffset = this._fileHints(builder, fileHints);

    EncryptSymmetricFileRequest.startEncryptSymmetricFileRequest(builder);
    typeof optionsOffset !== 'undefined' && EncryptSymmetricFileRequest.addOptions(builder, optionsOffset);
    typeof fileHintsOffset !== 'undefined' && EncryptSymmetricFileRequest.addFileHints(builder, fileHintsOffset);
    EncryptSymmetricFileRequest.addInput(builder, inputOffset);
    EncryptSymmetricFileRequest.addOutput(builder, outputOffset);
    EncryptSymmetricFileRequest.addPassphrase(builder, passphraseOffset);
    const offset = EncryptSymmetricFileRequest.endEncryptSymmetricFileRequest(builder);
    builder.finish(offset);
    const result = await this.call('encryptSymmetricFile', builder.asUint8Array());
    return this._intResponse(result);
  }

  static async generate(options) {
    const builder = new flatbuffers.Builder(0);

    const optionsOffset = this._options(builder, options);

    GenerateRequest.startGenerateRequest(builder);
    typeof optionsOffset !== 'undefined' && GenerateRequest.addOptions(builder, optionsOffset);
    const offset = GenerateRequest.endGenerateRequest(builder);
    builder.finish(offset);
    const result = await this.call('generate', builder.asUint8Array());
    return this._keyPairResponse(result);
  }

  static async getPrivateKeyMetadata(privateKey) {
    const builder = new flatbuffers.Builder(0);
    const privateKeyOffset = builder.createString(privateKey);
    GetPrivateKeyMetadataRequest.startGetPrivateKeyMetadataRequest(builder);
    GetPrivateKeyMetadataRequest.addPrivateKey(builder, privateKeyOffset);
    const offset = GetPrivateKeyMetadataRequest.endGetPrivateKeyMetadataRequest(builder);
    builder.finish(offset);
    const result = await this.call('getPrivateKeyMetadata', builder.asUint8Array());
    return this._privateKeyMetadataResponse(result);
  }

  static async getPublicKeyMetadata(publicKey) {
    const builder = new flatbuffers.Builder(0);
    const publicKeyOffset = builder.createString(publicKey);
    GetPublicKeyMetadataRequest.startGetPublicKeyMetadataRequest(builder);
    GetPublicKeyMetadataRequest.addPublicKey(builder, publicKeyOffset);
    const offset = GetPublicKeyMetadataRequest.endGetPublicKeyMetadataRequest(builder);
    builder.finish(offset);
    const result = await this.call('getPublicKeyMetadata', builder.asUint8Array());
    return this._publiKeyMetadataResponse(result);
  }

  static async convertPrivateKeyToPublicKey(privateKey) {
    const builder = new flatbuffers.Builder(0);
    const privateKeyOffset = builder.createString(privateKey);
    ConvertPrivateKeyToPublicKeyRequest.startConvertPrivateKeyToPublicKeyRequest(builder);
    ConvertPrivateKeyToPublicKeyRequest.addPrivateKey(builder, privateKeyOffset);
    const offset = ConvertPrivateKeyToPublicKeyRequest.endConvertPrivateKeyToPublicKeyRequest(builder);
    builder.finish(offset);
    const result = await this.call('convertPrivateKeyToPublicKey', builder.asUint8Array());
    return this._stringResponse(result);
  }

  static async call(name, bytes) {
    try {
      let result;

      if (this.useJSI) {
        if (!this.loaded) {
          this.loaded = await FastOpenPGPNativeModules.install();
          console.log(this.TAG, `(${name})`, 'JSI install:', this.loaded ? 'Installed' : 'Not Installed');
        }

        if (this.loaded) {
          const buff = bytes.buffer.slice(bytes.byteOffset, bytes.byteLength + bytes.byteOffset);
          result = await global.FastOpenPGPCallPromise(name, buff);

          if (typeof result === 'string') {
            throw new Error(result);
          }
        } else {
          console.log(this.TAG, `(${name})`, 'cant use JSI in debug mode, fallback to NativeModules');
          result = await FastOpenPGPNativeModules.callJSI(name, Array.from(bytes));
        }
      } else {
        result = await FastOpenPGPNativeModules.call(name, Array.from(bytes));
      }

      return this._responseBuffer(result);
    } catch (e) {
      throw e;
    }
  }

  static _responseBuffer(result) {
    if (!result) {
      throw new Error('empty result');
    }

    var rawResponse;

    if (result.hasOwnProperty('length')) {
      const resultArray = result;
      rawResponse = new Uint8Array(resultArray);
    } else {
      const resultBytes = result;
      rawResponse = new Uint8Array(resultBytes, 0, resultBytes.byteLength);
    }

    return new flatbuffers.ByteBuffer(rawResponse);
  }

  static _stringResponse(result) {
    const response = StringResponse.getRootAsStringResponse(result);
    const error = response.error();

    if (error) {
      throw new Error('stringResponse: ' + error);
    }

    return response.output() || '';
  }

  static _intResponse(result) {
    const response = IntResponse.getRootAsIntResponse(result);
    const error = response.error();

    if (error) {
      throw new Error('intResponse: ' + error);
    }

    return Number(response.output());
  }

  static _boolResponse(result) {
    const response = BoolResponse.getRootAsBoolResponse(result);
    const error = response.error();

    if (error) {
      throw new Error('boolResponse: ' + error);
    }

    return response.output();
  }

  static _entity(builder, options) {
    var _options$passphrase;

    if (!options) {
      return;
    }

    const passphraseOffset = builder.createString((_options$passphrase = options.passphrase) !== null && _options$passphrase !== void 0 ? _options$passphrase : '');
    const privateKeyOffset = builder.createString(options.privateKey);
    const publicKeyOffset = builder.createString(options.publicKey);
    model.Entity.startEntity(builder);
    model.Entity.addPassphrase(builder, passphraseOffset);
    model.Entity.addPrivateKey(builder, privateKeyOffset);
    model.Entity.addPublicKey(builder, publicKeyOffset);
    return model.Entity.endEntity(builder);
  }

  static _fileHints(builder, options) {
    var _options$fileName, _options$modTime, _options$isBinary;

    if (!options) {
      return;
    }

    const fileNameOffset = builder.createString((_options$fileName = options.fileName) !== null && _options$fileName !== void 0 ? _options$fileName : '');
    const modTimeOffset = builder.createString((_options$modTime = options.modTime) !== null && _options$modTime !== void 0 ? _options$modTime : '');
    model.FileHints.startFileHints(builder);
    model.FileHints.addFileName(builder, fileNameOffset);
    model.FileHints.addModTime(builder, modTimeOffset);
    model.FileHints.addIsBinary(builder, (_options$isBinary = options.isBinary) !== null && _options$isBinary !== void 0 ? _options$isBinary : false);
    return model.FileHints.endFileHints(builder);
  }

  static _keyOptions(builder, options) {
    if (!options) {
      return;
    }

    model.KeyOptions.startKeyOptions(builder);
    typeof options.cipher !== 'undefined' && model.KeyOptions.addCipher(builder, options.cipher);
    typeof options.compression !== 'undefined' && model.KeyOptions.addCompression(builder, options.compression);
    typeof options.compressionLevel !== 'undefined' && model.KeyOptions.addCompressionLevel(builder, options.compressionLevel);
    typeof options.hash !== 'undefined' && model.KeyOptions.addHash(builder, options.hash);
    typeof options.rsaBits !== 'undefined' && model.KeyOptions.addRsaBits(builder, options.rsaBits);
    return model.KeyOptions.endKeyOptions(builder);
  }

  static _options(builder, options) {
    var _options$name, _options$comment, _options$email, _options$passphrase2;

    if (!options) {
      return;
    }

    const nameOffset = builder.createString((_options$name = options.name) !== null && _options$name !== void 0 ? _options$name : '');
    const commentOffset = builder.createString((_options$comment = options.comment) !== null && _options$comment !== void 0 ? _options$comment : '');
    const emailOffset = builder.createString((_options$email = options.email) !== null && _options$email !== void 0 ? _options$email : '');
    const passphraseOffset = builder.createString((_options$passphrase2 = options.passphrase) !== null && _options$passphrase2 !== void 0 ? _options$passphrase2 : '');

    const keyOffset = this._keyOptions(builder, options.keyOptions);

    model.Options.startOptions(builder);
    model.Options.addName(builder, nameOffset);
    model.Options.addComment(builder, commentOffset);
    model.Options.addEmail(builder, emailOffset);
    model.Options.addPassphrase(builder, passphraseOffset);
    typeof keyOffset !== 'undefined' && model.Options.addKeyOptions(builder, keyOffset);
    return model.Options.endOptions(builder);
  }

  static _keyPairResponse(result) {
    const response = KeyPairResponse.getRootAsKeyPairResponse(result);
    const error = response.error();

    if (error) {
      throw new Error('keyPairResponse: ' + error);
    }

    const output = response.output();

    if (!output) {
      throw new Error('empty output');
    }

    return {
      privateKey: output.privateKey() || '',
      publicKey: output.publicKey() || ''
    };
  }

  static _publiKeyMetadataResponse(result) {
    const response = PublicKeyMetadataResponse.getRootAsPublicKeyMetadataResponse(result);
    const error = response.error();

    if (error) {
      throw new Error('publicKeyMetadataResponse: ' + error);
    }

    const output = response.output();

    if (!output) {
      throw new Error('empty output');
    }

    return {
      keyID: output.keyId() || '',
      keyIDShort: output.keyIdShort() || '',
      creationTime: output.creationTime() || '',
      fingerprint: output.fingerprint() || '',
      keyIDNumeric: output.keyIdNumeric() || '',
      isSubKey: output.isSubKey()
    };
  }

  static _privateKeyMetadataResponse(result) {
    const response = PrivateKeyMetadataResponse.getRootAsPrivateKeyMetadataResponse(result);
    const error = response.error();

    if (error) {
      throw new Error('privateKeyMetadataResponse: ' + error);
    }

    const output = response.output();

    if (!output) {
      throw new Error('empty output');
    }

    return {
      keyID: output.keyId() || '',
      keyIDShort: output.keyIdShort() || '',
      creationTime: output.creationTime() || '',
      fingerprint: output.fingerprint() || '',
      keyIDNumeric: output.keyIdNumeric() || '',
      isSubKey: output.isSubKey(),
      encrypted: output.encrypted()
    };
  }

}

_defineProperty(OpenPGP, "useJSI", false);

_defineProperty(OpenPGP, "loaded", false);

_defineProperty(OpenPGP, "TAG", '[FastOpenPGP]');
//# sourceMappingURL=index.js.map